# montelo.client
This server handles creating traces and logs.

The `montelo.client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil
* pydantic

## Getting Started

In your own code, to use this library to connect and interact with montelo.client,
you can run the following:

```python

import montelo.client
from montelo.client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:3002
# See configuration.py for a list of all supported configuration parameters.
configuration = montelo.client.Configuration(
    host = "http://localhost:3002"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): bearer
configuration = montelo.client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with montelo.client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = montelo.client.DatapointApi(api_client)
    dataset_slug = 'dataset_slug_example' # str | 
    add_to_dataset_input = montelo.client.AddToDatasetInput() # AddToDatasetInput | 

    try:
        api_response = api_instance.datapoint_controller_add_to_dataset_by_slug(dataset_slug, add_to_dataset_input)
        print("The response of DatapointApi->datapoint_controller_add_to_dataset_by_slug:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DatapointApi->datapoint_controller_add_to_dataset_by_slug: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:3002*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DatapointApi* | [**datapoint_controller_add_to_dataset_by_slug**](montelo/client/docs/DatapointApi.md#datapoint_controller_add_to_dataset_by_slug) | **POST** /dataset/{datasetSlug}/datapoint | 
*DatapointApi* | [**datapoint_controller_batch_add_to_dataset_by_slug**](montelo/client/docs/DatapointApi.md#datapoint_controller_batch_add_to_dataset_by_slug) | **POST** /dataset/{datasetSlug}/datapoint/batch | 
*DatapointRunApi* | [**datapoint_run_controller_create_datapoint_run**](montelo/client/docs/DatapointRunApi.md#datapoint_run_controller_create_datapoint_run) | **POST** /datapoint-run | 
*DatapointRunApi* | [**datapoint_run_controller_update_datapoint_run**](montelo/client/docs/DatapointRunApi.md#datapoint_run_controller_update_datapoint_run) | **PATCH** /datapoint-run | 
*DatasetApi* | [**dataset_controller_create**](montelo/client/docs/DatasetApi.md#dataset_controller_create) | **POST** /dataset | 
*DatasetApi* | [**dataset_controller_delete**](montelo/client/docs/DatasetApi.md#dataset_controller_delete) | **DELETE** /dataset/{datasetId} | 
*DatasetApi* | [**dataset_controller_get_all_datasets**](montelo/client/docs/DatasetApi.md#dataset_controller_get_all_datasets) | **GET** /dataset | 
*DatasetApi* | [**dataset_controller_get_full_dataset**](montelo/client/docs/DatasetApi.md#dataset_controller_get_full_dataset) | **GET** /dataset/{datasetId} | 
*ExperimentApi* | [**experiment_controller_create**](montelo/client/docs/ExperimentApi.md#experiment_controller_create) | **POST** /dataset/{datasetSlug}/experiment | 
*ExperimentApi* | [**experiment_controller_get_paginated_datapoints_for_experiment**](montelo/client/docs/ExperimentApi.md#experiment_controller_get_paginated_datapoints_for_experiment) | **GET** /experiment/{experimentId}/datapoints | 
*HealthApi* | [**health_controller_check**](montelo/client/docs/HealthApi.md#health_controller_check) | **GET** /health | 
*LogsApi* | [**logs_controller_create_log**](montelo/client/docs/LogsApi.md#logs_controller_create_log) | **POST** /logs | 
*LogsApi* | [**logs_controller_end_log**](montelo/client/docs/LogsApi.md#logs_controller_end_log) | **PATCH** /logs/{logId}/end | 


## Documentation For Models

 - [AddToDatasetInput](montelo/client/docs/AddToDatasetInput.md)
 - [BatchAddToDatasetInput](montelo/client/docs/BatchAddToDatasetInput.md)
 - [CreateDatapointRunInput](montelo/client/docs/CreateDatapointRunInput.md)
 - [CreateDatasetInput](montelo/client/docs/CreateDatasetInput.md)
 - [CreateExperimentInput](montelo/client/docs/CreateExperimentInput.md)
 - [CreateLogInput](montelo/client/docs/CreateLogInput.md)
 - [DatapointDto](montelo/client/docs/DatapointDto.md)
 - [DatapointRunDto](montelo/client/docs/DatapointRunDto.md)
 - [DatasetDto](montelo/client/docs/DatasetDto.md)
 - [DeleteSuccessDto](montelo/client/docs/DeleteSuccessDto.md)
 - [EndLogInput](montelo/client/docs/EndLogInput.md)
 - [EventQueuedDto](montelo/client/docs/EventQueuedDto.md)
 - [ExperimentDto](montelo/client/docs/ExperimentDto.md)
 - [ExperimentWithDatapointsDto](montelo/client/docs/ExperimentWithDatapointsDto.md)
 - [FullDatasetDto](montelo/client/docs/FullDatasetDto.md)
 - [FullDatasetWithCountDto](montelo/client/docs/FullDatasetWithCountDto.md)
 - [HealthControllerCheck200Response](montelo/client/docs/HealthControllerCheck200Response.md)
 - [HealthControllerCheck200ResponseInfoValue](montelo/client/docs/HealthControllerCheck200ResponseInfoValue.md)
 - [HealthControllerCheck503Response](montelo/client/docs/HealthControllerCheck503Response.md)
 - [LogInput](montelo/client/docs/LogInput.md)
 - [PaginatedExperimentWithDatapointsDto](montelo/client/docs/PaginatedExperimentWithDatapointsDto.md)
 - [TokenInfo](montelo/client/docs/TokenInfo.md)
 - [TraceInput](montelo/client/docs/TraceInput.md)
 - [UpdateDatapointRunInput](montelo/client/docs/UpdateDatapointRunInput.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearer"></a>
### bearer

- **Type**: Bearer authentication (JWT)


## Author




